Skip to contents

Converts a date to a combined ISO year and quarter string of the form "yyyy-Qn".

Usage

date_to_isoyearquarter_c(x = lubridate::today())

# Default S3 method
date_to_isoyearquarter_c(x)

# S3 method for class 'character'
date_to_isoyearquarter_c(x = lubridate::today())

# S3 method for class 'Date'
date_to_isoyearquarter_c(x = lubridate::today())

Arguments

x

A Date object, or a character string in the format 'yyyy-mm-dd'.

Value

ISO yearquarter as a character vector (e.g. "2021-Q3").

Details

The output combines the ISO year (see date_to_isoyear_c()) and the ISO-week-based quarter (see date_to_isoquarter_c()), for example "2021-Q3".

See also

vignette("date_conversion", package = "cstime") for worked date, ISO year and ISO week conversions. No vignette runs this function.

Other date-to-character converters: date_to_calmonth_c(), date_to_calyear_c(), date_to_calyearmonth_c(), date_to_isoquarter_c(), date_to_isoweek_c(), date_to_isoyear_c(), date_to_isoyearweek_c()

Examples

date_to_isoyearquarter_c(as.Date("2021-08-11"))
#> [1] "2021-Q3"
date_to_isoyearquarter_c("2021-01-01")
#> [1] "2020-Q4"