Converts a date to its ISO 8601 week number, returned as a number.
Details
ISO weeks run Monday to Sunday and are numbered 1 to 52 or 53. Week 1 is the week containing the first Thursday of the ISO year.
See also
vignette("date_conversion", package = "cstime"), which runs this
function.
Other date-to-number converters:
date_to_calmonth_n(),
date_to_calyear_n(),
date_to_isoquarter_n(),
date_to_isoyear_n()
Examples
date_to_isoweek_n(as.Date("2021-08-11"))
#> [1] 32
date_to_isoweek_n("2021-01-01")
#> [1] 53