ISO yearweek to ISO year (character)
Source:R/conversion_date_isoweek_isoyear.R
isoyearweek_to_isoyear_c.RdExtracts the ISO year from an ISO yearweek string and returns it as a character string.
Usage
isoyearweek_to_isoyear_c(x)
# Default S3 method
isoyearweek_to_isoyear_c(x)
# S3 method for class 'character'
isoyearweek_to_isoyear_c(x)Details
The input is split on the hyphen into year and week, and the year part is returned. The week part is ignored.
See also
vignette("cstime", package = "cstime") and
vignette("date_conversion", package = "cstime"), which both run this
function.
Other ISO yearweek-to-character converters:
isoyearweek_to_isoquarter_c(),
isoyearweek_to_isoweek_c(),
isoyearweek_to_isoyearquarter_c()